diff --git a/../natb_CY48R1.0_default/arpifs/phys_ec/cumastrn.F90 b/arpifs/phys_ec/cumastrn.F90
index d4613edeb2..199b5df4e6 100644
--- a/../natb_CY48R1.0_default/arpifs/phys_ec/cumastrn.F90
+++ b/arpifs/phys_ec/cumastrn.F90
@@ -213,6 +213,7 @@ SUBROUTINE CUMASTRN &
 !      08-12-20 : Added separate fields for lightning parameterization  P. Lopez.
 !      20-10-12 : SPP abstraction and revision     M. Leutbecher & S. Lang
 !      15-11-21 : Added PVDISCU, vert-integrated convective dissipation rate R.Forbes
+!      21-02-23 : Added RDXFAC, possibility to scale cloud base mass flux
 !------------------------------------------------------------------------------------------
 
 USE MODEL_PHYSICS_ECMWF_MOD , ONLY : MODEL_PHYSICS_ECMWF_TYPE
@@ -377,7 +378,7 @@ ASSOCIATE(LMFCUCA=>YDML_PHY_EC%YRECUMF%LMFCUCA, LMFDD=>YDML_PHY_EC%YRECUMF%LMFDD
  & NJKT3=>YDML_PHY_EC%YRECUMF%NJKT3, NJKT5=>YDML_PHY_EC%YRECUMF%NJKT5, RCAPDCYCL=>YDML_PHY_EC%YRECUMF%RCAPDCYCL, &
  & RDEPTHS=>YDML_PHY_EC%YRECUMF%RDEPTHS, RCUCOV =>YDML_PHY_EC%YRECUMF%RCUCOV, &
  & RMFCFL=>YDML_PHY_EC%YRECUMF%RMFCFL, RMFCMIN=>YDML_PHY_EC%YRECUMF%RMFCMIN, RMFLIA=>YDML_PHY_EC%YRECUMF%RMFLIA, &
- & RMFSOLCT=>YDML_PHY_EC%YRECUMF%RMFSOLCT, RCAPQADV=>YDML_PHY_EC%YRECUMF%RCAPQADV,&
+ & RMFSOLCT=>YDML_PHY_EC%YRECUMF%RMFSOLCT, RCAPQADV=>YDML_PHY_EC%YRECUMF%RCAPQADV, RDXFAC=>YDML_PHY_EC%YRECUMF%RDXFAC,&
  & RMFSOLTQ=>YDML_PHY_EC%YRECUMF%RMFSOLTQ, RMFSOLUV=>YDML_PHY_EC%YRECUMF%RMFSOLUV, &
  & RMINCAPE=>YDML_PHY_EC%YRECUMF%RMINCAPE, RTAUA=>YDML_PHY_EC%YRECUMF%RTAUA, &
  & RUVPER=>YDML_PHY_EC%YRECUMF%RUVPER, RMFADVW=>YDML_PHY_EC%YRECUMF%RMFADVW,RMFADVWDD=>YDML_PHY_EC%YRECUMF%RMFADVWDD,&
@@ -437,9 +438,9 @@ ZKMFL(:)=0.0_JPRB
 
 CALL CUBASEN &
  & ( YDML_PHY_SLIN%YREPHLI,YDML_PHY_EC%YRECLDP,YDML_PHY_EC%YRECUMF, YDSPP_CONFIG,&
- & KIDIA,    KFDIA,    KLON,     KLEV,     NJKT1,  .FALSE.,&
+ & KIDIA,    KFDIA,    KLON,     KLEV,     NJKT1,  .FALSE., LDLAND,&
  & ZTENH,    ZQENH,    PGEOH,    PAPH,&
- & PQHFL,    PAHFS,    PGP2DSPP, ZKMFL,&
+ & PQHFL,    PAHFS,    PTENQA,   PGP2DSPP, ZKMFL,&
  & PTEN,     PQEN,     PQSEN,    PGEO,&
  & PTU,      PQU,      PLU,      ZKINEU,   ZWUBASE,&
  & ILAB,     LDCUM,    LDSC,     KCBOT,    KBOTSC,&
@@ -752,6 +753,14 @@ DO JL=KIDIA,KFDIA
 !! CFL limit as function of resolution used in DWD ICON model
 ! ZMFCFL(JL) = 2._JPRB*MIN(2._JPRB,1._JPRB + 2.5E-5_JPRB*ZDX(JL))
   IF(LDCUM(JL).AND.KTYPE(JL) == 1) THEN
+
+    ! scale ZDX, e.g. to use cloud base mass flux as for ZDX = 700m (=TCo15999) resolution 
+    ! use RDXFAC=12.5 (=15999/1279) at TCo1279 and RDXFAC=6.25  (=15999/2559) at TCo2559
+    ! which corresponds to a reduction of cloud base mass flux by a factor of 6 at TCo1279
+    ! and by a factor of 5 at TCo2559
+
+    ZDX(JL) = ZDX(JL) / RDXFAC 
+
     ZTAURES=1.0_JPRB+1.60_JPRB*ZDX(JL)/125.E3_JPRB
     ! for the 10-1 km resolution range increase ZTAURES
     IF(ZDX(JL)<8.E3_JPRB) THEN
